COMPMID-596: Port HOGDetector to new validation

Change-Id: I73231fc71c5166268e6c909b7930b7e034f3794e
Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/118876
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
Tested-by: Jenkins <bsgcomp@arm.com>
diff --git a/arm_compute/core/HOGInfo.h b/arm_compute/core/HOGInfo.h
index f555742..90d44e3 100644
--- a/arm_compute/core/HOGInfo.h
+++ b/arm_compute/core/HOGInfo.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2018 ARM Limited.
+ * Copyright (c) 2016-2018 ARM Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -129,13 +129,13 @@
      * @return The Size2D data object which stores the number of cells per block stride along the x and y directions
      */
     Size2D num_cells_per_block_stride() const;
     /** Calculates the number of blocks for the given image size
      *
      * @param[in] image_size The input image size data object
      *
      * @return The Size2D data object which stores the number of blocks along the x and y directions
      */
-    Size2D num_blocks_per_image(const Size2D &image_size) const;
+    Size2D num_block_positions_per_image(const Size2D &image_size) const;
 
 private:
     Size2D      _cell_size;
@@ -129,13 +129,13 @@
      */
     Size2D num_cells_per_block_stride() const;
-    /** Calculates the number of blocks for the given image size
+    /** Calculates the number of block positions for the given image size
      *
      * @param[in] image_size The input image size data object
@@ -129,13 +129,13 @@
      * @param[in] image_size The input image size data object
      *
-     * @return The Size2D data object which stores the number of blocks along the x and y directions
+     * @return The Size2D data object which stores the number of block positions along the x and y directions
      */